@@ -52,22 +52,27 @@ def process_and_moose_ct_files(ct_dir: str, mask_dir: str, moose_model: str, acc
 
     with Progress() as progress_bar:
         task = progress_bar.add_task("[cyan] MOOSE-ing CT files...", total=len(ct_files))
-
+        
         for ct_file in ct_files:
             base_name = os.path.basename(ct_file).split('.')[0]
-
+            
             ct_file_dir = os.path.join(ct_dir, base_name)
             create_directory(ct_file_dir)
             move_file(ct_file, os.path.join(ct_file_dir, os.path.basename(ct_file)))
-
+            
             mask_file_dir = os.path.join(mask_dir, base_name)
             create_directory(mask_file_dir)
-
+            
             progress_bar.update(task, advance=0, description=f"[cyan] Running MOOSE on {base_name}...")
 
+            ct_file = glob.glob(os.path.join(ct_file_dir,"*.nii*"))[0]
+            
             with open(os.devnull, 'w') as devnull:
                 with contextlib.redirect_stdout(devnull), contextlib.redirect_stderr(devnull):
-                    moose(moose_model, ct_file_dir, mask_file_dir, accelerator)
+                    moose(model_names="clin_ct_body",
+                          input_data=ct_file,
+                          accelerator=accelerator,
+                          output_dir=mask_file_dir)
 
             progress_bar.update(task, advance=0, description=f"[cyan] Completed MOOSE on {base_name}, cleaning up...")
 
@@ -147,7 +152,7 @@ def copy_and_rename_file(src, dst, subdir):
     os.rename(os.path.join(dst, os.path.basename(src)), new_file)
 
 
-def preprocess(subject_dir: str, dicom_files_flag: bool, num_workers: int = None):
+def preprocess(subject_dir: str, dicom_files_flag: bool, num_workers: int = None, coreg_flag: bool = True):
     """
     Preprocesses the images in the subject directory
     :param puma_compliant_subjects: The puma compliant subjects
@@ -156,11 +161,12 @@ def preprocess(subject_dir: str, dicom_files_flag: bool, num_workers: int = None
     if num_workers is None:
         num_workers = multiprocessing.cpu_count()
 
-    ct_file = glob.glob(os.path.join(subject_dir, '*CT*.nii*'))
     pt_file = glob.glob(os.path.join(subject_dir, '*PT*.nii*'))
-    resliced_ct_file = os.path.join(subject_dir, constants.RESAMPLED_PREFIX + '_' +
-                                    os.path.basename(ct_file[0]))
-    reslice_identity(sitk.ReadImage(pt_file[0]), sitk.ReadImage(ct_file[0]), resliced_ct_file, is_label_image=False)
+    if coreg_flag:
+        ct_file = glob.glob(os.path.join(subject_dir, '*CT*.nii*'))
+        resliced_ct_file = os.path.join(subject_dir, constants.RESAMPLED_PREFIX + '_' +
+                                        os.path.basename(ct_file[0]))
+        reslice_identity(sitk.ReadImage(pt_file[0]), sitk.ReadImage(ct_file[0]), resliced_ct_file, is_label_image=False)
 
     # set orca working directory
  
@@ -168,31 +174,36 @@ def preprocess(subject_dir: str, dicom_files_flag: bool, num_workers: int = None
     create_directory(orca_working_dir)
 
     # create CT and PET folders
-    ct_dir = os.path.join(orca_working_dir, constants.MODALITIES[1])
+    if coreg_flag:
+        ct_dir = os.path.join(orca_working_dir, constants.MODALITIES[1])
+    else:
+        ct_dir=[]
     pt_dir = os.path.join(orca_working_dir, constants.MODALITIES[0])
     mask_dir = os.path.join(orca_working_dir, constants.MASK_FOLDER)
-    create_directory(ct_dir)
+    if coreg_flag: create_directory(ct_dir)
     create_directory(pt_dir)
 
 
     # Move or copy and rename files
     ct_files = glob.glob(os.path.join(subject_dir, '*CT*.nii*'))
-    for ct_file in ct_files: move_file(ct_file, ct_dir) if dicom_files_flag else copy_file(ct_file, ct_dir)
+    if coreg_flag: 
+        for ct_file in ct_files: move_file(ct_file, ct_dir) if dicom_files_flag else copy_file(ct_file, ct_dir)
     pt_files = glob.glob(os.path.join(subject_dir, '*PT*.nii*'))
     for pt_file in pt_files: move_file(pt_file, pt_dir) if dicom_files_flag else copy_file(pt_file, pt_dir)
 
-    # Run moosez to get the masks
-    process_and_moose_ct_files(ct_dir, mask_dir, constants.MOOSE_MODEL, constants.ACCELERATOR)
+    if coreg_flag:
+        # Run moosez to get the masks
+        process_and_moose_ct_files(ct_dir, mask_dir, constants.MOOSE_MODEL, constants.ACCELERATOR)
 
-    # remove the prefix from the mask files
-    for mask_file in glob.glob(os.path.join(mask_dir, constants.MOOSE_PREFIX + '*')):
-        new_mask_file = re.sub(rf'{constants.MOOSE_PREFIX}', '', mask_file)
-        os.rename(mask_file, new_mask_file)
-        # for ORCA the whole body contour is needed, so no masks are removed. 
-        #change_mask_labels(new_mask_file, constants.MOOSE_LABEL_INDEX, ["Arms"])
+        # remove the prefix from the mask files
+        for mask_file in glob.glob(os.path.join(mask_dir, constants.MOOSE_PREFIX + '*')):
+            new_mask_file = re.sub(rf'{constants.MOOSE_PREFIX}', '', mask_file)
+            os.rename(mask_file, new_mask_file)
+            # for ORCA the whole body contour is needed, so no masks are removed. 
+            #change_mask_labels(new_mask_file, constants.MOOSE_LABEL_INDEX, ["Arms"])
 
-    # process the mask files for ORCA
-    process_mask(mask_dir)
+        # process the mask files for ORCA
+        process_mask(mask_dir)
 
     return orca_working_dir, ct_dir, pt_dir, mask_dir
 
@@ -498,6 +509,15 @@ def process_mask(mask_dir: str) -> None:
     """
     # ORCA is only using the mask of the resampled CT, the reference space is that of PET
     mask_files = sorted(glob.glob(os.path.join(mask_dir, '*.nii*')))
+    # Rename to remove the "clin_CT_body_segmentation_"
+    for mask_file in mask_files:
+        mask_file = pathlib.Path(mask_file)
+        new_name = mask_file.name.replace("clin_CT_body_segmentation_", "")
+        new_path = mask_file.with_name(new_name)
+        mask_file.rename(new_path)
+    # Get the files with the new file-names
+    mask_files = sorted(glob.glob(os.path.join(mask_dir, '*.nii*')))
+
     with Progress() as progress:
         task = progress.add_task("[cyan] Processing mask files ", total=len(mask_files))
 
