@@ -2,6 +2,9 @@ def init():
     global model_path
     model_path = None
 
+    global resolution
+    resolution = None
+
     global pet_path
     pet_path = None
 
